@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2021 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2000-2026 Stephen Williams (steve@icarus.com)
  * Copyright CERN 2012 / Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
@@ -70,7 +70,7 @@ static bool get_const_argument(NetExpr*exp, verinum&res)
 	  }
 
 	  default:
-	    assert(0);;
+	    ivl_assert(*exp, 0);;
       }
 
       return true;
@@ -90,14 +90,25 @@ void Statement::elaborate_sig(Design*, NetScope*) const
 {
 }
 
-static void sig_check_data_type(Design*des, NetScope*scope,
-			        PWire *wire, NetNet *sig)
+static void sig_check_data_type(Design*des, const NetScope*scope,
+			        const PWire *wire, NetNet *sig)
 {
       ivl_type_t type = sig->net_type();
 
       if (!type)
 	    return;
 
+      if ((sig->type() == NetNet::WIRE) && (sig->data_type() != IVL_VT_LOGIC)) {
+	    if (gn_cadence_types_flag) {
+		  sig->type(NetNet::UNRESOLVED_WIRE);
+	    } else {
+		  cerr << wire->get_fileline() << ": error: Net `"
+		       << wire->basename() << "` can not be of type `"
+		       << sig->data_type() << "`." << endl;
+		  des->errors++;
+	    }
+      }
+
       if (type->packed()) {
 	    switch (type->base_type()) {
 	    case IVL_VT_LOGIC: // 4-state packed is allowed by the standard
@@ -130,8 +141,8 @@ static void sig_check_data_type(Design*des, NetScope*scope,
       }
 }
 
-static void sig_check_port_type(Design*des, NetScope*scope,
-			        PWire *wire, NetNet *sig)
+static void sig_check_port_type(Design*des, const NetScope*scope,
+			        const PWire *wire, const NetNet *sig)
 {
       if (sig->port_type() == NetNet::PREF) {
 	    cerr << wire->get_fileline() << ": sorry: "
@@ -233,7 +244,7 @@ static void elaborate_sig_tasks(Design*des, NetScope*scope,
       for (mtask_it_t cur = tasks.begin()
 		 ; cur != tasks.end() ; ++ cur ) {
 	    NetScope*tscope = scope->child( hname_t((*cur).first) );
-	    assert(tscope);
+	    ivl_assert(*(*cur).second, tscope);
 	    (*cur).second->elaborate_sig(des, tscope);
       }
 }
@@ -292,7 +303,7 @@ bool Module::elaborate_sig(Design*des, NetScope*scope) const
 	      // wires within the scope.
 	    map<perm_string,PWire*>::const_iterator wt;
 	    for (unsigned cc = 0 ;  cc < pp->expr.size() ;  cc += 1) {
-		  pform_name_t port_path (pp->expr[cc]->path());
+		  pform_name_t port_path (pp->expr[cc]->path().name);
 		    // A concatenated wire of a port really should not
 		    // have any hierarchy.
 		  if (port_path.size() != 1) {
@@ -403,9 +414,8 @@ void netclass_t::elaborate_sig(Design*des, PClass*pclass)
 		       << "." << endl;
 	    }
 
-	    list<netrange_t> nil_list;
 	    /* NetNet*sig = */ new NetNet(class_scope_, cur->first, NetNet::REG,
-				    nil_list, use_type);
+					  use_type);
       }
 
       for (map<perm_string,PFunction*>::iterator cur = pclass->funcs.begin()
@@ -439,18 +449,8 @@ bool PGate::elaborate_sig(Design*, NetScope*) const
       return true;
 }
 
-bool PGBuiltin::elaborate_sig(Design*, NetScope*) const
-{
-      return true;
-}
-
-bool PGAssign::elaborate_sig(Design*, NetScope*) const
-{
-      return true;
-}
-
 bool PGModule::elaborate_sig_mod_(Design*des, NetScope*scope,
-				  Module*rmod) const
+				  const Module*rmod) const
 {
       bool flag = true;
 
@@ -460,7 +460,7 @@ bool PGModule::elaborate_sig_mod_(Design*des, NetScope*scope,
 	      // I know a priori that the elaborate_scope created the scope
 	      // already, so just look it up as a child of the current scope.
 	    NetScope*my_scope = instance[idx];
-	    assert(my_scope);
+	    ivl_assert(*this, my_scope);
 
 	    if (my_scope->parent() != scope) {
 		  cerr << get_fileline() << ": internal error: "
@@ -469,7 +469,7 @@ bool PGModule::elaborate_sig_mod_(Design*des, NetScope*scope,
 		       << " instead of " << scope_path(scope)
 		       << endl;
 	    }
-	    assert(my_scope->parent() == scope);
+	    ivl_assert(*this, my_scope->parent() == scope);
 
 	    if (! rmod->elaborate_sig(des, my_scope))
 		  flag = false;
@@ -528,7 +528,7 @@ bool PGenerate::elaborate_sig(Design*des,  NetScope*container) const
 		  cerr << get_fileline() << ": debug: Elaborate nets in "
 		       << "scope " << scope_path(*cur)
 		       << " in generate " << id_number << endl;
-	    flag = elaborate_sig_(des, *cur) & flag;
+	    flag &= elaborate_sig_(des, *cur) && flag;
       }
 
       return flag;
@@ -574,6 +574,7 @@ bool PGenerate::elaborate_sig_(Design*des, NetScope*scope) const
 {
 	// Scan the declared PWires to elaborate the obvious signals
 	// in the current scope.
+      bool flag = true;
       typedef map<perm_string,PWire*>::const_iterator wires_it_t;
       for (wires_it_t wt = wires.begin()
 		 ; wt != wires.end() ; ++ wt ) {
@@ -584,7 +585,8 @@ bool PGenerate::elaborate_sig_(Design*des, NetScope*scope) const
 		  cerr << get_fileline() << ": debug: Elaborate PWire "
 		       << cur->basename() << " in scope " << scope_path(scope) << endl;
 
-	    cur->elaborate_sig(des, scope);
+	    const NetNet* res = cur->elaborate_sig(des, scope);
+	    flag &= (res != nullptr);
       }
 
       elaborate_sig_funcs(des, scope, funcs);
@@ -593,23 +595,23 @@ bool PGenerate::elaborate_sig_(Design*des, NetScope*scope) const
       typedef list<PGenerate*>::const_iterator generate_it_t;
       for (generate_it_t cur = generate_schemes.begin()
 		 ; cur != generate_schemes.end() ; ++ cur ) {
-	    (*cur) -> elaborate_sig(des, scope);
+	    flag &= (*cur)->elaborate_sig(des, scope);
       }
 
       typedef list<PGate*>::const_iterator pgate_list_it_t;
       for (pgate_list_it_t cur = gates.begin()
 		 ; cur != gates.end() ; ++ cur ) {
-	    (*cur) ->elaborate_sig(des, scope);
+	    flag &= (*cur)->elaborate_sig(des, scope);
       }
 
       typedef list<PProcess*>::const_iterator proc_it_t;
       for (proc_it_t cur = behaviors.begin()
 		 ; cur != behaviors.end() ; ++ cur ) {
-	    (*cur) -> statement() -> elaborate_sig(des, scope);
+	    (*cur)->statement()->elaborate_sig(des, scope);
       }
 
 
-      return true;
+      return flag;
 }
 
 
@@ -627,7 +629,7 @@ void PFunction::elaborate_sig(Design*des, NetScope*scope) const
       scope->set_elab_stage(2);
 
       perm_string fname = scope->basename();
-      assert(scope->type() == NetScope::FUNC);
+      ivl_assert(*this, scope->type() == NetScope::FUNC);
 
       elaborate_sig_wires_(des, scope);
 
@@ -661,7 +663,7 @@ void PFunction::elaborate_sig(Design*des, NetScope*scope) const
 			ivl_assert(*this, ret_type);
 		  }
 	    } else {
-		  netvector_t*tmp = new netvector_t(IVL_VT_LOGIC);
+		  const netvector_t*tmp = new netvector_t(IVL_VT_LOGIC);
 		  ret_type = tmp;
 	    }
 
@@ -672,8 +674,7 @@ void PFunction::elaborate_sig(Design*des, NetScope*scope) const
 			if (return_type_)
 			      return_type_->pform_dump(cerr, 8);
 		  }
-		  list<netrange_t> ret_unpacked;
-		  ret_sig = new NetNet(scope, fname, NetNet::REG, ret_unpacked, ret_type);
+		  ret_sig = new NetNet(scope, fname, NetNet::REG, ret_type);
 
 		  ret_sig->set_line(*this);
 		  ret_sig->port_type(NetNet::POUTPUT);
@@ -688,7 +689,8 @@ void PFunction::elaborate_sig(Design*des, NetScope*scope) const
 
       vector<NetNet*>ports;
       vector<NetExpr*>pdef;
-      elaborate_sig_ports_(des, scope, ports, pdef);
+      vector<perm_string> port_names;
+      elaborate_sig_ports_(des, scope, ports, pdef, port_names);
 
       NetFuncDef*def = new NetFuncDef(scope, ret_sig, ports, pdef);
 
@@ -716,13 +718,14 @@ void PFunction::elaborate_sig(Design*des, NetScope*scope) const
  */
 void PTask::elaborate_sig(Design*des, NetScope*scope) const
 {
-      assert(scope->type() == NetScope::TASK);
+      ivl_assert(*this, scope->type() == NetScope::TASK);
 
       elaborate_sig_wires_(des, scope);
 
       vector<NetNet*>ports;
       vector<NetExpr*>pdefs;
-      elaborate_sig_ports_(des, scope, ports, pdefs);
+      vector<perm_string> port_names;
+      elaborate_sig_ports_(des, scope, ports, pdefs, port_names);
       NetTaskDef*def = new NetTaskDef(scope, ports, pdefs);
       scope->set_task_def(def);
 
@@ -732,11 +735,14 @@ void PTask::elaborate_sig(Design*des, NetScope*scope) const
 }
 
 void PTaskFunc::elaborate_sig_ports_(Design*des, NetScope*scope,
-				     vector<NetNet*>&ports, vector<NetExpr*>&pdefs) const
+				     vector<NetNet*> &ports,
+				     vector<NetExpr*> &pdefs,
+				     vector<perm_string> &port_names) const
 {
       if (ports_ == 0) {
 	    ports.clear();
 	    pdefs.clear();
+	    port_names.clear();
 
 	      /* Make sure the function has at least one input
 		 port. If it fails this test, print an error
@@ -755,6 +761,7 @@ void PTaskFunc::elaborate_sig_ports_(Design*des, NetScope*scope,
 
       ports.resize(ports_->size());
       pdefs.resize(ports_->size());
+      port_names.resize(ports_->size());
 
       for (size_t idx = 0 ; idx < ports_->size() ; idx += 1) {
 
@@ -817,6 +824,7 @@ void PTaskFunc::elaborate_sig_ports_(Design*des, NetScope*scope,
 	    }
 
 	    ports[idx] = tmp;
+	    port_names[idx] = port_name;
 	    pdefs[idx] = tmp_def;
 	    if (scope->type()==NetScope::FUNC && tmp->port_type()!=NetNet::PINPUT) {
 		  cerr << tmp->get_fileline() << ": error: "
@@ -931,13 +939,13 @@ void PWhile::elaborate_sig(Design*des, NetScope*scope) const
 	    statement_->elaborate_sig(des, scope);
 }
 
-bool test_ranges_eeq(const vector<netrange_t>&lef, const vector<netrange_t>&rig)
+bool test_ranges_eeq(const netranges_t&lef, const netranges_t&rig)
 {
       if (lef.size() != rig.size())
 	    return false;
 
-      vector<netrange_t>::const_iterator lcur = lef.begin();
-      vector<netrange_t>::const_iterator rcur = rig.begin();
+      netranges_t::const_iterator lcur = lef.begin();
+      netranges_t::const_iterator rcur = rig.begin();
       while (lcur != lef.end()) {
 	    if (lcur->get_msb() != rcur->get_msb())
 		  return false;
@@ -952,9 +960,9 @@ bool test_ranges_eeq(const vector<netrange_t>&lef, const vector<netrange_t>&rig)
 }
 
 ivl_type_t PWire::elaborate_type(Design*des, NetScope*scope,
-			         const std::vector<netrange_t>&packed_dimensions) const
+			         const netranges_t &packed_dimensions) const
 {
-      vector_type_t *vec_type = dynamic_cast<vector_type_t*>(set_data_type_.get());
+      const vector_type_t *vec_type = dynamic_cast<vector_type_t*>(set_data_type_.get());
       if (set_data_type_ && !vec_type) {
 	    ivl_assert(*this, packed_dimensions.empty());
 	    return set_data_type_->elaborate_type(des, scope);
@@ -995,13 +1003,27 @@ ivl_type_t PWire::elaborate_type(Design*des, NetScope*scope,
  * elaboration this creates an object in the design that represents the
  * defined item.
  */
-NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
+NetNet* PWire::elaborate_sig(Design*des, NetScope*scope)
 {
 	// This sets the vector or array dimension size that will
 	// cause a warning. For now, these warnings are permanently
 	// enabled.
       const long warn_dimension_size = 1 << 30;
 
+	// Check if we elaborated this signal earlier because it was
+	// used in another declaration.
+      if (NetNet*sig = scope->find_signal(name_))
+            return sig;
+
+      if (is_elaborating_) {
+	    cerr << get_fileline() << ": error: Circular dependency "
+		    "detected in declaration of '" << name_ << "'."
+		 << endl;
+	    des->errors += 1;
+	    return 0;
+      }
+      is_elaborating_ = true;
+
       NetNet::Type wtype = type_;
       if (wtype == NetNet::IMPLICIT)
 	    wtype = NetNet::WIRE;
@@ -1023,7 +1045,7 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
       }
 
       unsigned wid = 1;
-      vector<netrange_t>packed_dimensions;
+      netranges_t packed_dimensions;
 
       des->errors += error_cnt_;
 
@@ -1046,7 +1068,7 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
 	    }
 
 	    bool dimensions_ok = true;
-	    vector<netrange_t> plist, nlist;
+	    netranges_t plist, nlist;
 	    /* If they exist get the port definition MSB and LSB */
 	    if (port_set_ && !port_.empty()) {
 		  if (debug_elaborate) {
@@ -1055,7 +1077,7 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
 		  }
 		  dimensions_ok &= evaluate_ranges(des, scope, this, plist, port_);
 	    }
-            assert(port_set_ || port_.empty());
+            ivl_assert(*this, port_set_ || port_.empty());
 
 	    /* If they exist get the net/etc. definition MSB and LSB */
 	    if (net_set_ && !net_.empty() && dimensions_ok) {
@@ -1066,7 +1088,7 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
 		  }
 		  dimensions_ok &= evaluate_ranges(des, scope, this, nlist, net_);
 	    }
-            assert(net_set_ || net_.empty());
+            ivl_assert(*this, net_set_ || net_.empty());
 
 	    if (debug_elaborate) {
 		  cerr << get_fileline() << ": PWire::elaborate_sig: "
@@ -1126,8 +1148,8 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
       }
 
       unsigned nattrib = 0;
-      attrib_list_t*attrib_list = evaluate_attributes(attributes, nattrib,
-						      des, scope);
+      const attrib_list_t*attrib_list = evaluate_attributes(attributes, nattrib,
+                                                            des, scope);
 
 	/* If the net type is supply0 or supply1, replace it
 	   with a simple wire with a pulldown/pullup with supply
@@ -1170,7 +1192,7 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
 	// unpacked_dimensions are empty this will just return the base type.
       type = elaborate_array_type(des, scope, *this, type, unpacked_);
 
-      list<netrange_t> unpacked_dimensions;
+      netranges_t unpacked_dimensions;
 	// If this is an unpacked array extract the base type and unpacked
 	// dimensions as these are separate properties of the NetNet.
       while (const netuarray_t *atype = dynamic_cast<const netuarray_t*>(type)) {
@@ -1184,7 +1206,7 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
 	    cerr << get_fileline() << ": debug: Create signal " << wtype;
 	    if (set_data_type_)
 		  cout << " " << *set_data_type_;
-	    cout << name_ << unpacked_dimensions << " in scope "
+	    cout << " " << name_ << unpacked_dimensions << " in scope "
 		 << scope_path(scope) << endl;
       }
 
@@ -1193,6 +1215,7 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
       if (wtype == NetNet::WIRE) sig->devirtualize_pins();
       sig->set_line(*this);
       sig->port_type(port_type_);
+      sig->lexical_pos(lexical_pos_);
 
       if (ivl_discipline_t dis = get_discipline()) {
 	    sig->set_discipline(dis);
@@ -1204,5 +1227,10 @@ NetNet* PWire::elaborate_sig(Design*des, NetScope*scope) const
       for (unsigned idx = 0 ;  idx < nattrib ;  idx += 1)
 	    sig->attribute(attrib_list[idx].key, attrib_list[idx].val);
 
+      sig->set_const(is_const_);
+
+      scope->rem_signal_placeholder(this);
+      is_elaborating_ = false;
+
       return sig;
 }
