@@ -470,7 +470,7 @@ extern int VLdebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 359 "parse.y"
+#line 466 "parse.y"
 
       bool flag;
 
@@ -484,6 +484,8 @@ union YYSTYPE
       char*text;
       std::list<perm_string>*perm_strings;
 
+      std::list<pform_ident_t>*identifiers;
+
       std::list<pform_port_t>*port_list;
 
       std::vector<pform_tf_port_t>* tf_ports;
@@ -511,9 +513,6 @@ union YYSTYPE
       std::list<PLet::let_port_t*>*let_port_lst;
       PLet::let_port_t*let_port_itm;
 
-      named_number_t* named_number;
-      std::list<named_number_t>* named_numbers;
-
       named_pexpr_t*named_pexpr;
       std::list<named_pexpr_t>*named_pexprs;
       struct parmvalue_t*parmvalue;
@@ -561,7 +560,7 @@ union YYSTYPE
 
       struct {
 	    data_type_t*type;
-	    std::list<PExpr*>*exprs;
+	    std::list<named_pexpr_t> *args;
       } class_declaration_extends;
 
       struct {
@@ -581,11 +580,14 @@ union YYSTYPE
       PSpecPath* specpath;
       std::list<index_component_t> *dimensions;
 
+      PTimingCheck::event_t* timing_check_event;
+      PTimingCheck::optional_args_t* spec_optional_args;
+
       LexicalScope::lifetime_t lifetime;
 
       enum typedef_t::basic_type typedef_basic_type;
 
-#line 589 "parse.h"
+#line 591 "parse.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
