@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2020 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 2001-2025 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -280,7 +280,7 @@ static char* draw_net_pull(ivl_net_logic_t lptr, ivl_drive_t drive, const char*l
  * to this nexus.
  */
 
-static char* draw_net_input_drive(ivl_nexus_t nex, ivl_nexus_ptr_t nptr)
+static char* draw_net_input_drive(const ivl_nexus_t nex, ivl_nexus_ptr_t nptr)
 {
       unsigned nptr_pin = ivl_nexus_ptr_pin(nptr);
       ivl_net_const_t cptr;
@@ -334,7 +334,7 @@ static char* draw_net_input_drive(ivl_nexus_t nex, ivl_nexus_ptr_t nptr)
 	    char *result = 0;
 	    ivl_expr_t d_rise, d_fall, d_decay;
             unsigned dly_width = 0;
-	    char *dly;
+	    const char *dly;
 
 	      /* Constants should have exactly 1 pin, with a literal value. */
 	    assert(nptr_pin == 0);
@@ -546,7 +546,7 @@ static void display_multi_driver_error(ivl_nexus_t nex, unsigned ndrivers,
 static ivl_nexus_ptr_t *drivers = 0x0;
 static unsigned adrivers = 0;
 
-void EOC_cleanup_drivers()
+void EOC_cleanup_drivers(void)
 {
       free(drivers);
       drivers = NULL;
@@ -651,18 +651,20 @@ static void draw_net_input_x(ivl_nexus_t nex,
       nex_data->flags |= nex_flags;
 
 	/* If the nexus has no drivers, then send a constant HiZ or
-	   0.0 into the net. */
+	   0.0 into the net. Use a lower case 'c' prefix for the
+	   constant to inform vvp that this is an undriven value. */
       if (ndrivers == 0) {
 	    unsigned wid = width_of_nexus(nex);
 	    int pull = (res == IVL_SIT_TRI0) || (res == IVL_SIT_TRI1);
 	      /* For real nets put 0.0. */
 	    if (signal_data_type_of_nexus(nex) == IVL_VT_REAL) {
 		  nex_private = draw_Cr_to_string(0.0);
+		  nex_private[0] = 'c';
 	    } else {
 		  unsigned jdx;
 		  char*tmp = malloc((pull ? 3 : 1) * wid + 5);
 		  nex_private = tmp;
-		  strcpy(tmp, pull ? "C8<" : "C4<");
+		  strcpy(tmp, pull ? "c8<" : "c4<");
 		  tmp += strlen(tmp);
 		  switch (res) {
 		      case IVL_SIT_TRI:
@@ -817,7 +819,7 @@ const char*draw_net_input(ivl_nexus_t nex)
       return nex_data->net_input;
 }
 
-const char*draw_island_net_input(ivl_island_t island, ivl_nexus_t nex)
+const char*draw_island_net_input(const ivl_island_t island, ivl_nexus_t nex)
 {
       struct vvp_nexus_data*nex_data = (struct vvp_nexus_data*)
 	    ivl_nexus_get_private(nex);
