@@ -78,7 +78,7 @@
 #line 2 "sdf_parse.y"
 
 /*
- * Copyright (c) 1998-2019 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1998-2023 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -655,22 +655,22 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,    83,    83,    84,    91,    92,    96,    97,    98,    99,
-     100,   101,   102,   103,   104,   105,   106,   110,   116,   124,
-     132,   140,   148,   156,   157,   158,   162,   163,   167,   175,
-     176,   180,   185,   193,   194,   199,   198,   205,   211,   216,
-     218,   220,   222,   229,   230,   234,   235,   238,   239,   245,
-     246,   250,   251,   252,   253,   254,   260,   261,   265,   270,
-     273,   281,   290,   293,   300,   304,   311,   317,   318,   323,
-     324,   325,   326,   327,   328,   329,   330,   334,   337,   340,
-     342,   349,   349,   353,   354,   355,   356,   357,   358,   359,
-     360,   361,   365,   367,   369,   371,   377,   379,   380,   381,
-     382,   383,   384,   385,   386,   390,   391,   392,   393,   397,
-     398,   402,   403,   407,   411,   412,   416,   420,   427,   429,
-     434,   434,   434,   439,   440,   441,   442,   443,   444,   445,
-     446,   450,   461,   468,   470,   475,   484,   487,   491,   494,
-     496,   502,   504,   515,   537,   540,   547,   548,   549,   550,
-     551,   552
+       0,    86,    86,    87,    94,    95,    99,   100,   101,   102,
+     103,   104,   105,   106,   107,   108,   109,   113,   123,   133,
+     143,   153,   163,   173,   178,   183,   191,   201,   208,   216,
+     226,   235,   240,   248,   249,   254,   253,   260,   266,   271,
+     273,   275,   277,   284,   285,   289,   290,   293,   296,   302,
+     303,   307,   308,   309,   310,   311,   317,   318,   322,   327,
+     330,   338,   347,   350,   357,   361,   371,   378,   379,   384,
+     385,   386,   387,   388,   389,   390,   391,   395,   398,   401,
+     403,   410,   410,   414,   415,   416,   417,   418,   419,   420,
+     421,   422,   426,   428,   430,   432,   438,   440,   441,   442,
+     443,   444,   445,   446,   447,   451,   452,   453,   454,   458,
+     459,   463,   464,   468,   472,   473,   477,   481,   487,   491,
+     498,   498,   498,   503,   504,   505,   506,   507,   508,   509,
+     510,   514,   525,   532,   534,   539,   548,   551,   555,   558,
+     560,   566,   568,   579,   601,   604,   611,   612,   613,   614,
+     615,   616
 };
 #endif
 
@@ -1573,438 +1573,522 @@ yyreduce:
   switch (yyn)
     {
   case 3: /* source_file: '(' K_DELAYFILE error ')'  */
-#line 85 "sdf_parse.y"
-      { vpi_printf("%s:%d:SDF ERROR: Invalid DELAYFILE format\n",
-		   sdf_parse_path, (yylsp[-2]).first_line);
+#line 88 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Invalid DELAYFILE format\n",
+	           sdf_parse_path, (yylsp[-2]).first_line);
       }
 #line 1581 "sdf_parse.c"
     break;
 
   case 17: /* sdfversion: '(' K_SDFVERSION QSTRING ')'  */
-#line 111 "sdf_parse.y"
-    { free((yyvsp[-1].string_val));
-    }
-#line 1588 "sdf_parse.c"
+#line 114 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Version: %s\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+	}
+	free((yyvsp[-1].string_val));
+      }
+#line 1592 "sdf_parse.c"
     break;
 
   case 18: /* design_name: '(' K_DESIGN QSTRING ')'  */
-#line 117 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: Design: %s\n",
-					sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
-        free((yyvsp[-1].string_val));
+#line 124 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Design: %s\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+	}
+	free((yyvsp[-1].string_val));
       }
-#line 1597 "sdf_parse.c"
+#line 1603 "sdf_parse.c"
     break;
 
   case 19: /* date: '(' K_DATE QSTRING ')'  */
-#line 125 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: Date: %s\n",
-					sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
-        free((yyvsp[-1].string_val));
+#line 134 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Date: %s\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+	}
+	free((yyvsp[-1].string_val));
       }
-#line 1606 "sdf_parse.c"
+#line 1614 "sdf_parse.c"
     break;
 
   case 20: /* vendor: '(' K_VENDOR QSTRING ')'  */
-#line 133 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: Vendor: %s\n",
-					sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
-        free((yyvsp[-1].string_val));
+#line 144 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Vendor: %s\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+	}
+	free((yyvsp[-1].string_val));
       }
-#line 1615 "sdf_parse.c"
+#line 1625 "sdf_parse.c"
     break;
 
   case 21: /* program_name: '(' K_PROGRAM QSTRING ')'  */
-#line 141 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: Program: %s\n",
-					sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
-        free((yyvsp[-1].string_val));
+#line 154 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Program: %s\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+	}
+	free((yyvsp[-1].string_val));
       }
-#line 1624 "sdf_parse.c"
+#line 1636 "sdf_parse.c"
     break;
 
   case 22: /* program_version: '(' K_VERSION QSTRING ')'  */
-#line 149 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: Program Version: %s\n",
-					sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+#line 164 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Program Version: %s\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+	}
 	free((yyvsp[-1].string_val));
       }
-#line 1633 "sdf_parse.c"
+#line 1647 "sdf_parse.c"
     break;
 
   case 23: /* hierarchy_divider: '(' K_DIVIDER '.' ')'  */
-#line 156 "sdf_parse.y"
-                          { sdf_use_hchar = '.'; }
-#line 1639 "sdf_parse.c"
+#line 174 "sdf_parse.y"
+      { sdf_use_hchar = '.';
+	if (sdf_flag_inform) vpi_printf("SDF INFO: %s:%d: Divider: \"%c\"\n",
+	                                sdf_parse_path, (yylsp[-3]).first_line, sdf_use_hchar);
+      }
+#line 1656 "sdf_parse.c"
     break;
 
   case 24: /* hierarchy_divider: '(' K_DIVIDER '/' ')'  */
-#line 157 "sdf_parse.y"
-                          { sdf_use_hchar = '/'; }
-#line 1645 "sdf_parse.c"
+#line 179 "sdf_parse.y"
+      { sdf_use_hchar = '/';
+	if (sdf_flag_inform) vpi_printf("SDF INFO: %s:%d: Divider: \"%c\"\n",
+	                                sdf_parse_path, (yylsp[-3]).first_line, sdf_use_hchar);
+      }
+#line 1665 "sdf_parse.c"
     break;
 
   case 25: /* hierarchy_divider: '(' K_DIVIDER HCHAR ')'  */
-#line 158 "sdf_parse.y"
-                            { /* sdf_use_hchar no-change */; }
-#line 1651 "sdf_parse.c"
+#line 184 "sdf_parse.y"
+      { /* sdf_use_hchar no-change */
+	if (sdf_flag_inform) vpi_printf("SDF INFO: %s:%d: Divider: \"%c\"\n",
+	                                sdf_parse_path, (yylsp[-3]).first_line, sdf_use_hchar);
+      }
+#line 1674 "sdf_parse.c"
+    break;
+
+  case 26: /* voltage: '(' K_VOLTAGE rtriple ')'  */
+#line 192 "sdf_parse.y"
+      { /* The value must be defined. */
+	if (! (yyvsp[-1].delay).defined) {
+	      vpi_printf("SDF ERROR: %s:%d: Chosen value not defined.\n",
+	                 sdf_parse_path, (yylsp[-3]).first_line);
+	} else if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Voltage: %f\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].delay).value);
+	}
+      }
+#line 1688 "sdf_parse.c"
+    break;
+
+  case 27: /* voltage: '(' K_VOLTAGE signed_real_number ')'  */
+#line 202 "sdf_parse.y"
+      { if (sdf_flag_inform) vpi_printf("SDF INFO: %s:%d: Voltage: %f\n",
+	                                sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].real_val));
+      }
+#line 1696 "sdf_parse.c"
     break;
 
   case 28: /* process: '(' K_PROCESS QSTRING ')'  */
-#line 168 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: Process: %s\n",
-					sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
+#line 209 "sdf_parse.y"
+      { if (sdf_flag_inform) vpi_printf("SDF INFO: %s:%d: Process: %s\n",
+	                                sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].string_val));
 	free((yyvsp[-1].string_val));
       }
-#line 1660 "sdf_parse.c"
-    break;
-
-  case 31: /* time_scale: '(' K_TIMESCALE REAL_NUMBER IDENTIFIER ')'  */
-#line 181 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: TIMESCALE : %f%s\n",
-					sdf_parse_path, (yylsp[-3]).first_line, (yyvsp[-2].real_val), (yyvsp[-1].string_val));
-	free((yyvsp[-1].string_val));
-      }
-#line 1669 "sdf_parse.c"
-    break;
-
-  case 32: /* time_scale: '(' K_TIMESCALE INTEGER IDENTIFIER ')'  */
-#line 186 "sdf_parse.y"
-      { if (sdf_flag_inform) vpi_printf("%s:%d:SDF INFO: TIMESCALE : %lu%s\n",
-					sdf_parse_path, (yylsp[-3]).first_line, (yyvsp[-2].int_val), (yyvsp[-1].string_val));
-	free((yyvsp[-1].string_val));
-      }
-#line 1678 "sdf_parse.c"
-    break;
-
-  case 35: /* $@1: %empty  */
-#line 199 "sdf_parse.y"
-      { sdf_select_instance((yyvsp[-1].string_val), (yyvsp[0].string_val)); /* find the instance in the design */}
-#line 1684 "sdf_parse.c"
-    break;
-
-  case 36: /* cell: '(' K_CELL celltype cell_instance $@1 timing_spec_list_opt ')'  */
-#line 202 "sdf_parse.y"
-      { free((yyvsp[-4].string_val));
-	if ((yyvsp[-3].string_val)) free((yyvsp[-3].string_val));
-      }
-#line 1692 "sdf_parse.c"
-    break;
-
-  case 37: /* cell: '(' K_CELL error ')'  */
-#line 206 "sdf_parse.y"
-      { vpi_printf("%s:%d: Syntax error in CELL\n",
-		   sdf_parse_path, (yylsp[-2]).first_line); }
-#line 1699 "sdf_parse.c"
-    break;
-
-  case 38: /* celltype: '(' K_CELLTYPE QSTRING ')'  */
-#line 212 "sdf_parse.y"
-      { (yyval.string_val) = (yyvsp[-1].string_val); }
 #line 1705 "sdf_parse.c"
     break;
 
-  case 39: /* cell_instance: '(' K_INSTANCE hierarchical_identifier ')'  */
+  case 29: /* temperature: '(' K_TEMPERATURE rtriple ')'  */
 #line 217 "sdf_parse.y"
-      { (yyval.string_val) = (yyvsp[-1].string_val); }
-#line 1711 "sdf_parse.c"
+      { /* The value must be defined. */
+	if (! (yyvsp[-1].delay).defined) {
+	      vpi_printf("SDF ERROR: %s:%d: Chosen value not defined.\n",
+	                 sdf_parse_path, (yylsp[-3]).first_line);
+	} else if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Temperature: %f\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].delay).value);
+	}
+      }
+#line 1719 "sdf_parse.c"
     break;
 
-  case 40: /* cell_instance: '(' K_INSTANCE ')'  */
-#line 219 "sdf_parse.y"
-      { (yyval.string_val) = strdup(""); }
-#line 1717 "sdf_parse.c"
+  case 30: /* temperature: '(' K_TEMPERATURE signed_real_number ')'  */
+#line 227 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: Temperature: %f\n",
+	                 sdf_parse_path, (yylsp[-2]).first_line, (yyvsp[-1].real_val));
+	}
+      }
+#line 1729 "sdf_parse.c"
     break;
 
-  case 41: /* cell_instance: '(' K_INSTANCE '*' ')'  */
-#line 221 "sdf_parse.y"
-      { (yyval.string_val) = 0; }
-#line 1723 "sdf_parse.c"
-    break;
-
-  case 42: /* cell_instance: '(' K_INSTANCE error ')'  */
-#line 223 "sdf_parse.y"
-      { vpi_printf("%s:%d:SDF ERROR: Invalid/malformed INSTANCE argument\n",
-		   sdf_parse_path, (yylsp[-2]).first_line);
-	    (yyval.string_val) = strdup(""); }
-#line 1731 "sdf_parse.c"
-    break;
-
-  case 46: /* timing_spec: '(' K_DELAY error ')'  */
+  case 31: /* time_scale: '(' K_TIMESCALE REAL_NUMBER IDENTIFIER ')'  */
 #line 236 "sdf_parse.y"
-      { vpi_printf("%s:%d: Syntax error in CELL DELAY SPEC\n",
-		   sdf_parse_path, (yylsp[-2]).first_line); }
+      { if (sdf_flag_inform) vpi_printf("SDF INFO: %s:%d: Timescale: %f%s\n",
+	                                sdf_parse_path, (yylsp[-3]).first_line, (yyvsp[-2].real_val), (yyvsp[-1].string_val));
+	free((yyvsp[-1].string_val));
+      }
 #line 1738 "sdf_parse.c"
     break;
 
-  case 48: /* timing_spec: '(' K_TIMINGCHECK error ')'  */
-#line 240 "sdf_parse.y"
-      { vpi_printf("%s:%d: Syntax error in TIMINGCHECK SPEC\n",
-		   sdf_parse_path, (yylsp[-2]).first_line); }
-#line 1745 "sdf_parse.c"
+  case 32: /* time_scale: '(' K_TIMESCALE INTEGER IDENTIFIER ')'  */
+#line 241 "sdf_parse.y"
+      { if (sdf_flag_inform) vpi_printf("SDF INFO: %s:%d: Timescale: %lu%s\n",
+	                                sdf_parse_path, (yylsp[-3]).first_line, (yyvsp[-2].int_val), (yyvsp[-1].string_val));
+	free((yyvsp[-1].string_val));
+      }
+#line 1747 "sdf_parse.c"
     break;
 
-  case 55: /* deltype: '(' error ')'  */
-#line 255 "sdf_parse.y"
-    { vpi_printf("%s:%d: SDF ERROR: Invalid/malformed delay type\n",
-		 sdf_parse_path, (yylsp[-2]).first_line); }
-#line 1752 "sdf_parse.c"
+  case 35: /* $@1: %empty  */
+#line 254 "sdf_parse.y"
+      { sdf_select_instance((yyvsp[-1].string_val), (yyvsp[0].string_val), (yylsp[0]).first_line); /* find the instance in the design */}
+#line 1753 "sdf_parse.c"
     break;
 
-  case 58: /* del_def: '(' K_IOPATH port_spec port_instance delval_list ')'  */
-#line 266 "sdf_parse.y"
-      { sdf_iopath_delays((yyvsp[-3].port_with_edge).vpi_edge, (yyvsp[-3].port_with_edge).string_val, (yyvsp[-2].string_val), &(yyvsp[-1].delval_list));
-	free((yyvsp[-3].port_with_edge).string_val);
-	free((yyvsp[-2].string_val));
+  case 36: /* cell: '(' K_CELL celltype cell_instance $@1 timing_spec_list_opt ')'  */
+#line 257 "sdf_parse.y"
+      { free((yyvsp[-4].string_val));
+	if ((yyvsp[-3].string_val)) free((yyvsp[-3].string_val));
       }
 #line 1761 "sdf_parse.c"
     break;
 
-  case 59: /* del_def: '(' K_IOPATH error ')'  */
-#line 271 "sdf_parse.y"
-      { vpi_printf("%s:%d: SDF ERROR: Invalid/malformed IOPATH\n",
+  case 37: /* cell: '(' K_CELL error ')'  */
+#line 261 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Syntax error in CELL\n",
 		   sdf_parse_path, (yylsp[-2]).first_line); }
 #line 1768 "sdf_parse.c"
     break;
 
+  case 38: /* celltype: '(' K_CELLTYPE QSTRING ')'  */
+#line 267 "sdf_parse.y"
+      { (yyval.string_val) = (yyvsp[-1].string_val); }
+#line 1774 "sdf_parse.c"
+    break;
+
+  case 39: /* cell_instance: '(' K_INSTANCE hierarchical_identifier ')'  */
+#line 272 "sdf_parse.y"
+      { (yyval.string_val) = (yyvsp[-1].string_val); }
+#line 1780 "sdf_parse.c"
+    break;
+
+  case 40: /* cell_instance: '(' K_INSTANCE ')'  */
+#line 274 "sdf_parse.y"
+      { (yyval.string_val) = strdup(""); }
+#line 1786 "sdf_parse.c"
+    break;
+
+  case 41: /* cell_instance: '(' K_INSTANCE '*' ')'  */
+#line 276 "sdf_parse.y"
+      { (yyval.string_val) = 0; }
+#line 1792 "sdf_parse.c"
+    break;
+
+  case 42: /* cell_instance: '(' K_INSTANCE error ')'  */
+#line 278 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Invalid/malformed INSTANCE argument\n",
+		   sdf_parse_path, (yylsp[-2]).first_line);
+	    (yyval.string_val) = strdup(""); }
+#line 1800 "sdf_parse.c"
+    break;
+
+  case 46: /* timing_spec: '(' K_DELAY error ')'  */
+#line 291 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Syntax error in CELL DELAY SPEC\n",
+	           sdf_parse_path, (yylsp[-2]).first_line); }
+#line 1807 "sdf_parse.c"
+    break;
+
+  case 47: /* timing_spec: '(' K_TIMINGCHECK tchk_def_list ')'  */
+#line 294 "sdf_parse.y"
+      { vpi_printf("SDF WARNING: %s:%d: TIMINGCHECK not supported.\n",
+	           sdf_parse_path, (yylsp[-2]).first_line); }
+#line 1814 "sdf_parse.c"
+    break;
+
+  case 48: /* timing_spec: '(' K_TIMINGCHECK error ')'  */
+#line 297 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Syntax error in TIMINGCHECK SPEC\n",
+	           sdf_parse_path, (yylsp[-2]).first_line); }
+#line 1821 "sdf_parse.c"
+    break;
+
+  case 55: /* deltype: '(' error ')'  */
+#line 312 "sdf_parse.y"
+    { vpi_printf("SDF ERROR: %s:%d: Invalid/malformed delay type\n",
+	         sdf_parse_path, (yylsp[-2]).first_line); }
+#line 1828 "sdf_parse.c"
+    break;
+
+  case 58: /* del_def: '(' K_IOPATH port_spec port_instance delval_list ')'  */
+#line 323 "sdf_parse.y"
+      { sdf_iopath_delays((yyvsp[-3].port_with_edge).vpi_edge, (yyvsp[-3].port_with_edge).string_val, (yyvsp[-2].string_val), &(yyvsp[-1].delval_list), (yylsp[-4]).first_line);
+	free((yyvsp[-3].port_with_edge).string_val);
+	free((yyvsp[-2].string_val));
+      }
+#line 1837 "sdf_parse.c"
+    break;
+
+  case 59: /* del_def: '(' K_IOPATH error ')'  */
+#line 328 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Invalid/malformed IOPATH\n",
+	           sdf_parse_path, (yylsp[-2]).first_line); }
+#line 1844 "sdf_parse.c"
+    break;
+
   case 60: /* del_def: '(' K_COND conditional_port_expr '(' K_IOPATH port_spec port_instance delval_list ')' ')'  */
-#line 275 "sdf_parse.y"
-      { if (sdf_flag_warning) vpi_printf("%s:%d: SDF WARNING: "
-					 "COND not supported.\n",
-					 sdf_parse_path, (yylsp[-8]).first_line);
+#line 332 "sdf_parse.y"
+      { if (sdf_flag_warning) vpi_printf("SDF WARNING: %s:%d: "
+	                                 "COND not supported.\n",
+	                                 sdf_parse_path, (yylsp[-8]).first_line);
 	free((yyvsp[-4].port_with_edge).string_val);
 	free((yyvsp[-3].string_val));
       }
-#line 1779 "sdf_parse.c"
+#line 1855 "sdf_parse.c"
     break;
 
   case 61: /* del_def: '(' K_COND QSTRING conditional_port_expr '(' K_IOPATH port_spec port_instance delval_list ')' ')'  */
-#line 283 "sdf_parse.y"
-      { if (sdf_flag_warning) vpi_printf("%s:%d: SDF WARNING: "
-					 "COND not supported.\n",
-					 sdf_parse_path, (yylsp[-9]).first_line);
+#line 340 "sdf_parse.y"
+      { if (sdf_flag_warning) vpi_printf("SDF WARNING: %s:%d: "
+	                                 "COND not supported.\n",
+	                                 sdf_parse_path, (yylsp[-9]).first_line);
 	free((yyvsp[-8].string_val));
 	free((yyvsp[-4].port_with_edge).string_val);
 	free((yyvsp[-3].string_val));
       }
-#line 1791 "sdf_parse.c"
+#line 1867 "sdf_parse.c"
     break;
 
   case 62: /* del_def: '(' K_COND error ')'  */
-#line 291 "sdf_parse.y"
-      { vpi_printf("%s:%d: SDF ERROR: Invalid/malformed COND\n",
-		   sdf_parse_path, (yylsp[-2]).first_line); }
-#line 1798 "sdf_parse.c"
+#line 348 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Invalid/malformed COND\n",
+	           sdf_parse_path, (yylsp[-2]).first_line); }
+#line 1874 "sdf_parse.c"
     break;
 
   case 63: /* del_def: '(' K_CONDELSE '(' K_IOPATH port_spec port_instance delval_list ')' ')'  */
-#line 294 "sdf_parse.y"
-      { if (sdf_flag_warning) vpi_printf("%s:%d: SDF WARNING: "
-					 "CONDELSE not supported.\n",
-					 sdf_parse_path, (yylsp[-7]).first_line);
+#line 351 "sdf_parse.y"
+      { if (sdf_flag_warning) vpi_printf("SDF WARNING: %s:%d: "
+	                                 "CONDELSE not supported.\n",
+	                                 sdf_parse_path, (yylsp[-7]).first_line);
 	free((yyvsp[-4].port_with_edge).string_val);
 	free((yyvsp[-3].string_val));
       }
-#line 1809 "sdf_parse.c"
+#line 1885 "sdf_parse.c"
     break;
 
   case 64: /* del_def: '(' K_CONDELSE error ')'  */
-#line 301 "sdf_parse.y"
-      { vpi_printf("%s:%d: SDF ERROR: Invalid/malformed CONDELSE\n",
-		   sdf_parse_path, (yylsp[-2]).first_line); }
-#line 1816 "sdf_parse.c"
+#line 358 "sdf_parse.y"
+      { vpi_printf("SDF ERROR: %s:%d: Invalid/malformed CONDELSE\n",
+	           sdf_parse_path, (yylsp[-2]).first_line); }
+#line 1892 "sdf_parse.c"
     break;
 
   case 65: /* del_def: '(' K_INTERCONNECT port_interconnect port_interconnect delval_list ')'  */
-#line 305 "sdf_parse.y"
-      { if (sdf_flag_warning) vpi_printf("%s:%d: SDF WARNING: "
-					 "INTERCONNECT not supported.\n",
-					 sdf_parse_path, (yylsp[-4]).first_line);
-	free((yyvsp[-3].string_val));
-	free((yyvsp[-2].string_val));
+#line 362 "sdf_parse.y"
+      { if (sdf_flag_inform) {
+	      vpi_printf("SDF INFO: %s:%d: INTERCONNECT with "
+	                 "port1 = %s index = %d, port2 = %s index = %d\n",
+	                 sdf_parse_path, (yylsp[-4]).first_line, (yyvsp[-3].interconnect_port).name, (yyvsp[-3].interconnect_port).index, (yyvsp[-2].interconnect_port).name, (yyvsp[-2].interconnect_port).index);
+	}
+	sdf_interconnect_delays((yyvsp[-3].interconnect_port), (yyvsp[-2].interconnect_port), &(yyvsp[-1].delval_list), (yylsp[-4]).first_line);
+	free((yyvsp[-3].interconnect_port).name);
+	free((yyvsp[-2].interconnect_port).name);
       }
-#line 1827 "sdf_parse.c"
+#line 1906 "sdf_parse.c"
     break;
 
   case 66: /* del_def: '(' K_INTERCONNECT error ')'  */
-#line 312 "sdf_parse.y"
-      { vpi_printf("%s:%d: SDF ERROR: Invalid/malformed INTERCONNECT\n",
-		   sdf_parse_path, (yylsp[-2]).first_line); }
-#line 1834 "sdf_parse.c"
-    break;
-
-  case 77: /* port_tchk: port_instance  */
-#line 335 "sdf_parse.y"
-      { free((yyvsp[0].string_val)); }
-#line 1840 "sdf_parse.c"
-    break;
-
-  case 78: /* port_tchk: cond_edge_start port_instance ')'  */
-#line 338 "sdf_parse.y"
-      { free((yyvsp[-1].string_val)); }
-#line 1846 "sdf_parse.c"
-    break;
-
-  case 79: /* port_tchk: cond_edge_start timing_check_condition port_spec ')'  */
-#line 341 "sdf_parse.y"
-      { free((yyvsp[-1].port_with_edge).string_val); }
-#line 1852 "sdf_parse.c"
-    break;
-
-  case 80: /* port_tchk: cond_edge_start QSTRING timing_check_condition port_spec ')'  */
-#line 343 "sdf_parse.y"
-      { free((yyvsp[-3].string_val));
-	free((yyvsp[-1].port_with_edge).string_val);
-      }
-#line 1860 "sdf_parse.c"
-    break;
-
-  case 81: /* $@2: %empty  */
-#line 349 "sdf_parse.y"
-        { start_edge_id(1); }
-#line 1866 "sdf_parse.c"
-    break;
-
-  case 82: /* cond_edge_start: '(' $@2 cond_edge_identifier  */
-#line 349 "sdf_parse.y"
-                                                   { stop_edge_id(); }
-#line 1872 "sdf_parse.c"
-    break;
-
-  case 92: /* timing_check_condition: port_interconnect  */
-#line 366 "sdf_parse.y"
-      { free((yyvsp[0].string_val)); }
-#line 1878 "sdf_parse.c"
-    break;
-
-  case 93: /* timing_check_condition: '~' port_interconnect  */
-#line 368 "sdf_parse.y"
-      { free((yyvsp[0].string_val)); }
-#line 1884 "sdf_parse.c"
-    break;
-
-  case 94: /* timing_check_condition: '!' port_interconnect  */
-#line 370 "sdf_parse.y"
-      { free((yyvsp[0].string_val)); }
-#line 1890 "sdf_parse.c"
-    break;
-
-  case 95: /* timing_check_condition: port_interconnect equality_operator scalar_constant  */
 #line 372 "sdf_parse.y"
-      { free((yyvsp[-2].string_val)); }
-#line 1896 "sdf_parse.c"
-    break;
-
-  case 96: /* conditional_port_expr: port  */
-#line 378 "sdf_parse.y"
-      { free((yyvsp[0].string_val)); }
-#line 1902 "sdf_parse.c"
-    break;
-
-  case 114: /* port_spec: port_instance  */
-#line 411 "sdf_parse.y"
-                  { (yyval.port_with_edge).vpi_edge = vpiNoEdge; (yyval.port_with_edge).string_val = (yyvsp[0].string_val); }
-#line 1908 "sdf_parse.c"
-    break;
-
-  case 115: /* port_spec: port_edge  */
-#line 412 "sdf_parse.y"
-                  { (yyval.port_with_edge) = (yyvsp[0].port_with_edge); }
+      { vpi_printf("SDF ERROR: %s:%d: Invalid/malformed INTERCONNECT\n",
+	           sdf_parse_path, (yylsp[-2]).first_line);
+      }
 #line 1914 "sdf_parse.c"
     break;
 
-  case 116: /* port_instance: port  */
-#line 416 "sdf_parse.y"
-         { (yyval.string_val) = (yyvsp[0].string_val); }
+  case 77: /* port_tchk: port_instance  */
+#line 396 "sdf_parse.y"
+      { free((yyvsp[0].string_val)); }
 #line 1920 "sdf_parse.c"
     break;
 
-  case 117: /* port: hierarchical_identifier  */
-#line 421 "sdf_parse.y"
-      { (yyval.string_val) = (yyvsp[0].string_val); }
+  case 78: /* port_tchk: cond_edge_start port_instance ')'  */
+#line 399 "sdf_parse.y"
+      { free((yyvsp[-1].string_val)); }
 #line 1926 "sdf_parse.c"
     break;
 
-  case 118: /* port_interconnect: hierarchical_identifier  */
-#line 428 "sdf_parse.y"
-      { (yyval.string_val) = (yyvsp[0].string_val); }
+  case 79: /* port_tchk: cond_edge_start timing_check_condition port_spec ')'  */
+#line 402 "sdf_parse.y"
+      { free((yyvsp[-1].port_with_edge).string_val); }
 #line 1932 "sdf_parse.c"
     break;
 
+  case 80: /* port_tchk: cond_edge_start QSTRING timing_check_condition port_spec ')'  */
+#line 404 "sdf_parse.y"
+      { free((yyvsp[-3].string_val));
+	free((yyvsp[-1].port_with_edge).string_val);
+      }
+#line 1940 "sdf_parse.c"
+    break;
+
+  case 81: /* $@2: %empty  */
+#line 410 "sdf_parse.y"
+        { start_edge_id(1); }
+#line 1946 "sdf_parse.c"
+    break;
+
+  case 82: /* cond_edge_start: '(' $@2 cond_edge_identifier  */
+#line 410 "sdf_parse.y"
+                                                   { stop_edge_id(); }
+#line 1952 "sdf_parse.c"
+    break;
+
+  case 92: /* timing_check_condition: port_interconnect  */
+#line 427 "sdf_parse.y"
+      { free((yyvsp[0].interconnect_port).name); }
+#line 1958 "sdf_parse.c"
+    break;
+
+  case 93: /* timing_check_condition: '~' port_interconnect  */
+#line 429 "sdf_parse.y"
+      { free((yyvsp[0].interconnect_port).name); }
+#line 1964 "sdf_parse.c"
+    break;
+
+  case 94: /* timing_check_condition: '!' port_interconnect  */
+#line 431 "sdf_parse.y"
+      { free((yyvsp[0].interconnect_port).name); }
+#line 1970 "sdf_parse.c"
+    break;
+
+  case 95: /* timing_check_condition: port_interconnect equality_operator scalar_constant  */
+#line 433 "sdf_parse.y"
+      { free((yyvsp[-2].interconnect_port).name); }
+#line 1976 "sdf_parse.c"
+    break;
+
+  case 96: /* conditional_port_expr: port  */
+#line 439 "sdf_parse.y"
+      { free((yyvsp[0].string_val)); }
+#line 1982 "sdf_parse.c"
+    break;
+
+  case 114: /* port_spec: port_instance  */
+#line 472 "sdf_parse.y"
+                  { (yyval.port_with_edge).vpi_edge = vpiNoEdge; (yyval.port_with_edge).string_val = (yyvsp[0].string_val); }
+#line 1988 "sdf_parse.c"
+    break;
+
+  case 115: /* port_spec: port_edge  */
+#line 473 "sdf_parse.y"
+                  { (yyval.port_with_edge) = (yyvsp[0].port_with_edge); }
+#line 1994 "sdf_parse.c"
+    break;
+
+  case 116: /* port_instance: port  */
+#line 477 "sdf_parse.y"
+         { (yyval.string_val) = (yyvsp[0].string_val); }
+#line 2000 "sdf_parse.c"
+    break;
+
+  case 117: /* port: hierarchical_identifier  */
+#line 482 "sdf_parse.y"
+      { (yyval.string_val) = (yyvsp[0].string_val); }
+#line 2006 "sdf_parse.c"
+    break;
+
+  case 118: /* port_interconnect: hierarchical_identifier  */
+#line 488 "sdf_parse.y"
+      { struct interconnect_port_s tmp = {(yyvsp[0].string_val), false, 0};
+	(yyval.interconnect_port) = tmp;
+      }
+#line 2014 "sdf_parse.c"
+    break;
+
   case 119: /* port_interconnect: hierarchical_identifier '[' INTEGER ']'  */
-#line 430 "sdf_parse.y"
-      { (yyval.string_val) = (yyvsp[-3].string_val);}
-#line 1938 "sdf_parse.c"
+#line 492 "sdf_parse.y"
+      { struct interconnect_port_s tmp = {(yyvsp[-3].string_val), true, (yyvsp[-1].int_val)};
+	(yyval.interconnect_port) = tmp;
+      }
+#line 2022 "sdf_parse.c"
     break;
 
   case 120: /* $@3: %empty  */
-#line 434 "sdf_parse.y"
+#line 498 "sdf_parse.y"
         {start_edge_id(0);}
-#line 1944 "sdf_parse.c"
+#line 2028 "sdf_parse.c"
     break;
 
   case 121: /* $@4: %empty  */
-#line 434 "sdf_parse.y"
+#line 498 "sdf_parse.y"
                                             {stop_edge_id();}
-#line 1950 "sdf_parse.c"
+#line 2034 "sdf_parse.c"
     break;
 
   case 122: /* port_edge: '(' $@3 edge_identifier $@4 port_instance ')'  */
-#line 435 "sdf_parse.y"
+#line 499 "sdf_parse.y"
       { (yyval.port_with_edge).vpi_edge = (yyvsp[-3].int_val); (yyval.port_with_edge).string_val = (yyvsp[-1].string_val); }
-#line 1956 "sdf_parse.c"
+#line 2040 "sdf_parse.c"
     break;
 
   case 123: /* edge_identifier: K_POSEDGE  */
-#line 439 "sdf_parse.y"
+#line 503 "sdf_parse.y"
               { (yyval.int_val) = vpiPosedge; }
-#line 1962 "sdf_parse.c"
+#line 2046 "sdf_parse.c"
     break;
 
   case 124: /* edge_identifier: K_NEGEDGE  */
-#line 440 "sdf_parse.y"
+#line 504 "sdf_parse.y"
               { (yyval.int_val) = vpiNegedge; }
-#line 1968 "sdf_parse.c"
+#line 2052 "sdf_parse.c"
     break;
 
   case 125: /* edge_identifier: K_01  */
-#line 441 "sdf_parse.y"
+#line 505 "sdf_parse.y"
               { (yyval.int_val) = vpiEdge01; }
-#line 1974 "sdf_parse.c"
+#line 2058 "sdf_parse.c"
     break;
 
   case 126: /* edge_identifier: K_10  */
-#line 442 "sdf_parse.y"
+#line 506 "sdf_parse.y"
               { (yyval.int_val) = vpiEdge10; }
-#line 1980 "sdf_parse.c"
+#line 2064 "sdf_parse.c"
     break;
 
   case 127: /* edge_identifier: K_0Z  */
-#line 443 "sdf_parse.y"
+#line 507 "sdf_parse.y"
               { (yyval.int_val) = vpiEdge0x; }
-#line 1986 "sdf_parse.c"
+#line 2070 "sdf_parse.c"
     break;
 
   case 128: /* edge_identifier: K_Z1  */
-#line 444 "sdf_parse.y"
+#line 508 "sdf_parse.y"
               { (yyval.int_val) = vpiEdgex1; }
-#line 1992 "sdf_parse.c"
+#line 2076 "sdf_parse.c"
     break;
 
   case 129: /* edge_identifier: K_1Z  */
-#line 445 "sdf_parse.y"
+#line 509 "sdf_parse.y"
               { (yyval.int_val) = vpiEdge1x; }
-#line 1998 "sdf_parse.c"
+#line 2082 "sdf_parse.c"
     break;
 
   case 130: /* edge_identifier: K_Z0  */
-#line 446 "sdf_parse.y"
+#line 510 "sdf_parse.y"
               { (yyval.int_val) = vpiEdgex0; }
-#line 2004 "sdf_parse.c"
+#line 2088 "sdf_parse.c"
     break;
 
   case 131: /* delval_list: delval_list delval  */
-#line 451 "sdf_parse.y"
+#line 515 "sdf_parse.y"
       { int idx;
 	(yyval.delval_list).count = (yyvsp[-1].delval_list).count;
 	for (idx = 0 ; idx < (yyval.delval_list).count ; idx += 1)
@@ -2015,77 +2099,77 @@ yyreduce:
 	      (yyval.delval_list).count += 1;
 	}
       }
-#line 2019 "sdf_parse.c"
+#line 2103 "sdf_parse.c"
     break;
 
   case 132: /* delval_list: delval  */
-#line 462 "sdf_parse.y"
+#line 526 "sdf_parse.y"
       { (yyval.delval_list).count = 1;
 	(yyval.delval_list).val[0] = (yyvsp[0].delay);
       }
-#line 2027 "sdf_parse.c"
+#line 2111 "sdf_parse.c"
     break;
 
   case 133: /* delval: rvalue  */
-#line 469 "sdf_parse.y"
+#line 533 "sdf_parse.y"
       { (yyval.delay) = (yyvsp[0].delay); }
-#line 2033 "sdf_parse.c"
+#line 2117 "sdf_parse.c"
     break;
 
   case 134: /* delval: '(' rvalue rvalue ')'  */
-#line 471 "sdf_parse.y"
+#line 535 "sdf_parse.y"
       { (yyval.delay) = (yyvsp[-2].delay);
-	vpi_printf("%s:%d: SDF WARNING: Pulse rejection limits ignored\n",
+	vpi_printf("SDF WARNING: %s:%d: Pulse rejection limits ignored\n",
 		   sdf_parse_path, (yylsp[-1]).first_line);
       }
-#line 2042 "sdf_parse.c"
+#line 2126 "sdf_parse.c"
     break;
 
   case 135: /* delval: '(' rvalue rvalue rvalue ')'  */
-#line 476 "sdf_parse.y"
+#line 540 "sdf_parse.y"
       { (yyval.delay) = (yyvsp[-3].delay);
-	vpi_printf("%s:%d: SDF WARNING: Pulse rejection limits ignored\n",
+	vpi_printf("SDF WARNING: %s:%d: Pulse rejection limits ignored\n",
 		   sdf_parse_path, (yylsp[-2]).first_line);
       }
-#line 2051 "sdf_parse.c"
+#line 2135 "sdf_parse.c"
     break;
 
   case 136: /* rvalue_opt: %empty  */
-#line 484 "sdf_parse.y"
+#line 548 "sdf_parse.y"
       { (yyval.delay).value = 0.0;
 	(yyval.delay).defined = 0;
       }
-#line 2059 "sdf_parse.c"
+#line 2143 "sdf_parse.c"
     break;
 
   case 138: /* rvalue: '(' signed_real_number ')'  */
-#line 492 "sdf_parse.y"
+#line 556 "sdf_parse.y"
       { (yyval.delay).defined = 1;
         (yyval.delay).value = (yyvsp[-1].real_val); }
-#line 2066 "sdf_parse.c"
+#line 2150 "sdf_parse.c"
     break;
 
   case 139: /* rvalue: '(' rtriple ')'  */
-#line 495 "sdf_parse.y"
+#line 559 "sdf_parse.y"
       { (yyval.delay) = (yyvsp[-1].delay); }
-#line 2072 "sdf_parse.c"
+#line 2156 "sdf_parse.c"
     break;
 
   case 140: /* rvalue: '(' ')'  */
-#line 497 "sdf_parse.y"
+#line 561 "sdf_parse.y"
       { (yyval.delay).defined = 0;
         (yyval.delay).value = 0.0; }
-#line 2079 "sdf_parse.c"
+#line 2163 "sdf_parse.c"
     break;
 
   case 141: /* hierarchical_identifier: IDENTIFIER  */
-#line 503 "sdf_parse.y"
+#line 567 "sdf_parse.y"
       { (yyval.string_val) = (yyvsp[0].string_val); }
-#line 2085 "sdf_parse.c"
+#line 2169 "sdf_parse.c"
     break;
 
   case 142: /* hierarchical_identifier: hierarchical_identifier HCHAR IDENTIFIER  */
-#line 505 "sdf_parse.y"
+#line 569 "sdf_parse.y"
       { int len = strlen((yyvsp[-2].string_val)) + strlen((yyvsp[0].string_val)) + 2;
 	char*tmp = realloc((yyvsp[-2].string_val), len);
 	strcat(tmp, ".");
@@ -2093,11 +2177,11 @@ yyreduce:
 	free((yyvsp[0].string_val));
 	(yyval.string_val) = tmp;
       }
-#line 2097 "sdf_parse.c"
+#line 2181 "sdf_parse.c"
     break;
 
   case 143: /* rtriple: signed_real_number_opt ':' signed_real_number_opt ':' signed_real_number_opt  */
-#line 516 "sdf_parse.y"
+#line 580 "sdf_parse.y"
       { switch(sdf_min_typ_max) {
 	    case _vpiDelaySelMinimum:
 	       (yyval.delay) = (yyvsp[-4].delay);
@@ -2111,67 +2195,67 @@ yyreduce:
 	}
 	  /* At least one of the values must be defined. */
 	if (! ((yyvsp[-4].delay).defined || (yyvsp[-2].delay).defined || (yyvsp[0].delay).defined)) {
-	      vpi_printf("%s:%d: SDF ERROR: rtriple must have at least one "
+	      vpi_printf("SDF ERROR: %s:%d: rtriple must have at least one "
 	                 "defined value.\n", sdf_parse_path, (yylsp[-4]).first_line);
 	}
       }
-#line 2119 "sdf_parse.c"
+#line 2203 "sdf_parse.c"
     break;
 
   case 144: /* signed_real_number_opt: %empty  */
-#line 537 "sdf_parse.y"
+#line 601 "sdf_parse.y"
       { (yyval.delay).value = 0.0;
 	(yyval.delay).defined = 0;
       }
-#line 2127 "sdf_parse.c"
+#line 2211 "sdf_parse.c"
     break;
 
   case 145: /* signed_real_number_opt: signed_real_number  */
-#line 541 "sdf_parse.y"
+#line 605 "sdf_parse.y"
       { (yyval.delay).value = (yyvsp[0].real_val);
 	(yyval.delay).defined = 1;
       }
-#line 2135 "sdf_parse.c"
+#line 2219 "sdf_parse.c"
     break;
 
   case 146: /* signed_real_number: REAL_NUMBER  */
-#line 547 "sdf_parse.y"
+#line 611 "sdf_parse.y"
                     { (yyval.real_val) = (yyvsp[0].real_val); }
-#line 2141 "sdf_parse.c"
+#line 2225 "sdf_parse.c"
     break;
 
   case 147: /* signed_real_number: '+' REAL_NUMBER  */
-#line 548 "sdf_parse.y"
+#line 612 "sdf_parse.y"
                     { (yyval.real_val) = (yyvsp[0].real_val); }
-#line 2147 "sdf_parse.c"
+#line 2231 "sdf_parse.c"
     break;
 
   case 148: /* signed_real_number: '-' REAL_NUMBER  */
-#line 549 "sdf_parse.y"
+#line 613 "sdf_parse.y"
                     { (yyval.real_val) = -(yyvsp[0].real_val); }
-#line 2153 "sdf_parse.c"
+#line 2237 "sdf_parse.c"
     break;
 
   case 149: /* signed_real_number: INTEGER  */
-#line 550 "sdf_parse.y"
+#line 614 "sdf_parse.y"
                 { (yyval.real_val) = (yyvsp[0].int_val); }
-#line 2159 "sdf_parse.c"
+#line 2243 "sdf_parse.c"
     break;
 
   case 150: /* signed_real_number: '+' INTEGER  */
-#line 551 "sdf_parse.y"
+#line 615 "sdf_parse.y"
                 { (yyval.real_val) = (yyvsp[0].int_val); }
-#line 2165 "sdf_parse.c"
+#line 2249 "sdf_parse.c"
     break;
 
   case 151: /* signed_real_number: '-' INTEGER  */
-#line 552 "sdf_parse.y"
+#line 616 "sdf_parse.y"
                 { (yyval.real_val) = -(yyvsp[0].int_val); }
-#line 2171 "sdf_parse.c"
+#line 2255 "sdf_parse.c"
     break;
 
 
-#line 2175 "sdf_parse.c"
+#line 2259 "sdf_parse.c"
 
       default: break;
     }
@@ -2369,10 +2453,10 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 555 "sdf_parse.y"
+#line 619 "sdf_parse.y"
 
 
 void yyerror(const char*msg)
 {
-      vpi_printf("%s:SDF ERROR: Too many errors: %s\n", sdf_parse_path, msg);
+      vpi_printf("SDF ERROR: %s: Too many errors: %s\n", sdf_parse_path, msg);
 }
